package com.ekexiu.project.msconsole.doctor;


import com.ekexiu.project.msconsole.system.vo.SessionUser;
import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.web.annotation.LoginUser;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.operate.Get;
import org.jfw.apt.web.annotation.operate.Post;
import org.jfw.apt.web.annotation.param.JdbcConn;
import org.jfw.util.PageQueryResult;
import org.jfw.util.StringUtil;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by TT on 2019/5/30.
 */


@Path("/doctor")
public class DoctorService {

    @Autowrie
    private DoctorDao doctorDao;

    public DoctorDao getDoctorDao() {
        return doctorDao;
    }

    public void setDoctorDao(DoctorDao doctorDao) {
        this.doctorDao = doctorDao;
    }

    @Post
    @Path
    public String insert(@JdbcConn(true)Connection con, @LoginUser SessionUser user,Doctor doctor)throws SQLException {
        String id = StringUtil.buildUUID();
        doctor.setId(id);
        doctor.setActive(true);
        doctor.setCreator(user.getId());
        doctor.setModifier(user.getId());
        doctor.setHospital(user.getId());
        doctorDao.insert(con, doctor);
        return id;
    }

    @Post
    @Path("/update")
    public void update(@JdbcConn(true)Connection con,@LoginUser SessionUser user,Doctor doctor)throws SQLException {
        doctor.setModifier(user.getId());
        doctorDao.update(con, doctor);
    }

    @Get
    @Path("/qo")
    public SessionDoctor query(@JdbcConn Connection con,String id)throws SQLException {
        return makeSessionDoctor(doctorDao.query(con, id));
    }

    @Get
    @Path("/pq")
    public PageQueryResult<SessionDoctor> pageQuery(@JdbcConn Connection con, String hospital, @Nullable Boolean active,@Nullable String name,@Nullable String department,int pageSize,int pageNo)throws SQLException {
        PageQueryResult<Doctor> pageQueryResult =  doctorDao.pageQuery(con, hospital, active, name == null ? null : "%" + name + "%", department == null ? null : "%" + department + "%", pageSize, pageNo);
        if (pageQueryResult != null) {
            List<Doctor> doctors = pageQueryResult.getData();
            List<SessionDoctor> sessionDoctors = new ArrayList<>();
            if (!doctors.isEmpty()) {
                for (Doctor doctor : doctors) {
                    sessionDoctors.add(makeSessionDoctor(doctor));
                }
                PageQueryResult<SessionDoctor> ret = new PageQueryResult<>();
                ret.setPageNo(pageQueryResult.getPageNo());
                ret.setPageSize(pageQueryResult.getPageSize());
                ret.setTotal(pageQueryResult.getTotal());
                ret.setData(sessionDoctors);
                return ret;
            }
        }
        return null;
    }

    @Get
    @Path("/ban")
    public void ban(@JdbcConn(true)Connection con,@LoginUser SessionUser user, String id)throws SQLException {
        doctorDao.ban(con, id, user.getId());
    }

    @Get
    @Path("/check")
    public SessionDoctor queryByAccount(@JdbcConn Connection con,String account)throws SQLException {
        return makeSessionDoctor(doctorDao.queryByAccount(con, account));
    }

    private static SessionDoctor makeSessionDoctor(Doctor doctor) {
        SessionDoctor sessionDoctor = new SessionDoctor();
        sessionDoctor.setAccount(doctor.getAccount());
        sessionDoctor.setName(doctor.getName());
        sessionDoctor.setHospital(doctor.getHospital());
        sessionDoctor.setDepartment(doctor.getDepartment());
        sessionDoctor.setId(doctor.getId());
        sessionDoctor.setClinicalTitle(doctor.getClinicalTitle());
        sessionDoctor.setTeachTitle(doctor.getTeachTitle());
        sessionDoctor.setPosition(doctor.getPosition());
        sessionDoctor.setDirection(doctor.getDirection());
        sessionDoctor.setDescp(doctor.getDescp());
        sessionDoctor.setImage(doctor.getImage());
        sessionDoctor.setActive(doctor.isActive());
        sessionDoctor.setCreateTime(doctor.getCreateTime());
        sessionDoctor.setModifyTime(doctor.getModifyTime());
        sessionDoctor.setCreator(doctor.getCreator());
        sessionDoctor.setModifier(doctor.getModifier());
        return sessionDoctor;
    }
}
